<h1 align="center">cilroy</h1>

<div align="center">

kilroy controller 🎛️

[![Multiplatform tests](https://github.com/kilroybot/cilroy/actions/workflows/test-multiplatform.yml/badge.svg)](https://github.com/kilroybot/cilroy/actions/workflows/test-multiplatform.yml)
[![Docker tests](https://github.com/kilroybot/cilroy/actions/workflows/test-docker.yml/badge.svg)](https://github.com/kilroybot/cilroy/actions/workflows/test-docker.yml)
[![Docs](https://github.com/kilroybot/cilroy/actions/workflows/docs.yml/badge.svg)](https://github.com/kilroybot/cilroy/actions/workflows/docs.yml)

</div>

---

TODO
